@@ -4,9 +4,8 @@ OC.L10N.register(
     "Notes" : "Noter",
     "The last viewed note cannot be accessed. " : "Den senest viste note kan ikke tilgås.",
     "The notes folder is not accessible: %s" : "Mappen med noter er ikke tilgængelig: %s",
-    "New note" : "Ny note",
-    "Encryption Error" : "Fejl i kryptering",
     "Error" : "Fejl",
+    "New note" : "Ny note",
     "Settings" : "Indstillinger",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
     "All notes" : "Alle noter",
@@ -18,6 +17,7 @@ OC.L10N.register(
     "Last week" : "Sidste uge",
     "This month" : "Denne måned",
     "Last month" : "Seneste måned",
+    "Rename" : "Omdøb",
     "Delete note" : "Slet note",
     "Remove from favorites" : "Fjernet fra favoritter",
     "Add to favorites" : "Føj til favoritter",
