@@ -2,11 +2,11 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Oharrak",
-    "New note" : "Ohar berria",
-    "Encryption Error" : "Zifratze errorea",
     "Error" : "Errorea",
+    "New note" : "Ohar berria",
     "Settings" : "Ezarpenak",
     "Deleted {title}" : "{title} ezabatuta",
+    "Deleted {number} notes" : "{number} ohar ezabatuta",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Gorde gabeko notak daude. Orrialdetik irtetzean aldaketa guztiak galduko dira!",
     "Folder to store your notes" : "Zure oharrak gordetzeko karpeta",
     "path to notes" : "oharretara bidea",
@@ -19,6 +19,7 @@ OC.L10N.register(
     "Last week" : "Azken astean",
     "This month" : "Hilabete honetan",
     "Last month" : "Azken hilabetean",
+    "Rename" : "Berrizendatu",
     "Delete note" : "Ezabatu oharra",
     "Remove from favorites" : "Kendu gogokoetatik",
     "Add to favorites" : "Gehitu gogokoetan",
