@@ -4,9 +4,8 @@ OC.L10N.register(
     "Notes" : "Jegyzetek",
     "The last viewed note cannot be accessed. " : "Az utoljára megtekintett jegyzet nem elérhető.",
     "The notes folder is not accessible: %s" : "A jegyzetek mappa nem érhető el: %s",
-    "New note" : "Új jegyzet",
-    "Encryption Error" : "Titkosítási hiba",
     "Error" : "Hiba",
+    "New note" : "Új jegyzet",
     "Distraction-free notes and writing" : "Figyelemelterelés nélküli jegyzetelés és írás",
     "Settings" : "Beállítások",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Mentetlen jegyzetek vannak. Az oldal elhagyásával a változások elvesznek.",
@@ -22,6 +21,7 @@ OC.L10N.register(
     "Last week" : "Előző hét",
     "This month" : "Ez a hónap",
     "Last month" : "Előző hónap",
+    "Rename" : "Átnevezés",
     "Delete note" : "Jegyzet törlése",
     "Remove from favorites" : "Eltávolítás a kedvencekből",
     "Add to favorites" : "Hozzáadás a kedvencekhez",
