@@ -4,9 +4,8 @@ OC.L10N.register(
     "Notes" : "Anteckningar",
     "The last viewed note cannot be accessed. " : "Den senast visade anteckningen kan inte nås.",
     "The notes folder is not accessible: %s" : "Anteckningsmappen är inte tillgänglig: %s",
-    "New note" : "Ny anteckning",
-    "Encryption Error" : "Krypteringsfel",
     "Error" : "Fel",
+    "New note" : "Ny anteckning",
     "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
     "Settings" : "Inställningar",
     "Deleted {title}" : "Raderad {title}",
@@ -21,7 +20,7 @@ OC.L10N.register(
     "Categories" : "Kategorier",
     "No search result for “{search}” in {category}" : "Inget sökresultat för “{search}” i {category}",
     "No search result for “{search}”" : "Inget sökresultat för “{search}”",
-    "Loading …" : "Laddar ...",
+    "Loading …" : "Läser in ...",
     "Search result for “{search}” in {category}" : "Sökresultat för “{search}” i {category}",
     "Search result for “{search}”" : "Sökresultat för “{search}”",
     "Today" : "Idag",
@@ -30,6 +29,8 @@ OC.L10N.register(
     "Last week" : "Förra veckan",
     "This month" : "Denna månad",
     "Last month" : "Förra månaden",
+    "Rename" : "Byt namn",
+    "Note's title" : "Anteckningens titel",
     "Delete note" : "Radera anteckning",
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till som favorit",
@@ -64,6 +65,7 @@ OC.L10N.register(
     "Updating settings has failed." : "Kunde inte uppdatera inställningar. ",
     "Fetching notes has failed." : "Kunde inte hämta anteckningar.",
     "Fetching note {id} has failed." : "Hämtning av anteckning {id} misslyckades.",
+    "Renaming note {id} has failed." : "Namnbyte av anteckning {id} misslyckades.",
     "Creating new note has failed." : "Kunde inte skapa ny anteckning.",
     "Updating note {id} has failed." : "Uppdatering av anteckning {id} misslyckades.",
     "Undo delete has failed for note {title}." : "Ångra radering misslyckades för anteckning {title}.",
