@@ -2,11 +2,13 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Ghi chép",
-    "New note" : "Ghi chú mới",
     "Error" : "Lỗi",
+    "New note" : "Ghi chú mới",
     "Settings" : "Thiết lập",
+    "Categories" : "Các hạng mục",
     "Today" : "Hôm nay",
     "Yesterday" : "Hôm qua",
+    "Rename" : "Đổi tên",
     "Remove from favorites" : "Xóa khỏi ưa thích",
     "Add to favorites" : "Thêm vào ưa thích",
     "Details" : "Thông tin",
